Documentation
¶
Overview ¶
Package ebml decodes EBML data.
EBML is short for Extensible Binary Meta Language. EBML specifies a binary and octet (byte) aligned format inspired by the principle of XML. EBML itself is a generalized description of the technique of binary markup. Like XML, it is completely agnostic to any data that it might contain. For a specification, see http://ebml.sourceforge.net/specs/
Index ¶
Constants ¶
This section is empty.
Variables ¶
var Verbose bool = false
Functions ¶
This section is empty.
Types ¶
type Element ¶
Element represents an EBML-encoded chunk of data.
func RootElement ¶
func RootElement(rs io.ReadSeeker) (*Element, error)
Creates the root element corresponding to the data available in r.
type ReachedPayloadError ¶
type ReachedPayloadError struct {
*Element
}
ReachedPayloadError is generated when a field tagged with ebmlstop:"1" is reached.
func (ReachedPayloadError) Error ¶
func (r ReachedPayloadError) Error() string
Click to show internal directories.
Click to hide internal directories.